@@ -27,4 +27,7 @@ from .storage import SVSyncStorage
 from .security import SigningInfo, ValidatingInfo, SecurityOptions
 
 # Tool classes
-from .scheduler import AsyncScheduler
\ No newline at end of file
+from .scheduler import AsyncScheduler
+
+# Logging class
+from .logger import SVSyncLogger
\ No newline at end of file
