@@ -24,16 +24,10 @@ class MetaData:
     def __init__(self, comp:Component=None) -> None:
         try:
             model = MetaDataModel.parse(bytes(Component.get_value(comp)))
-            self.source = model.source
-            self.tseqno = model.tseqno
-            self.nopcks = model.nopcks
+            self.source, self.tseqno, self.nopcks = model.source, model.tseqno, model.nopcks
         except (ValueError,TypeError,IndexError,DecodeError):
-            self.source = b''
-            self.tseqno = 0
-            self.nopcks = 0
+            self.source, self.tseqno, self.nopcks = b'', 0, 0
     def encode(self) -> Component:
         model = MetaDataModel()
-        model.source = self.source
-        model.tseqno = self.tseqno
-        model.nopcks = self.nopcks
+        model.source, model.tseqno, model.nopcks = self.source, self.tseqno, self.nopcks
         return Component.from_bytes(model.encode())
\ No newline at end of file
