@@ -7,7 +7,7 @@
 # Basic Libraries
 from typing import List, Optional
 from enum import Enum
-import struct
+from struct import unpack_from
 # NDN Imports
 from ndn.encoding import Component
 from ndn.encoding import TlvModel, BytesField, UintField
@@ -32,7 +32,7 @@ class StateVectorComponentModel(TlvModel):
 # Class Purpose:
 #   to contain all the info of a state vector.
 class StateVectorModel:
-    def __init__(self, value:List[StateVectorComponentModel]=[]) -> None:
+    def __init__(self, value:List[StateVectorComponentModel]) -> None:
         self.value = value
     def encode(self) -> bytearray:
         component_wires = [v.encode() for v in self.value]
@@ -57,7 +57,7 @@ class StateVectorModel:
         if pos + length != len(buf):
             return None
         # Decode components
-        ret = StateVectorModel()
+        ret = StateVectorModel([])
         ret.value = []
         while pos < len(buf):
             # Node ID
@@ -77,13 +77,13 @@ class StateVectorModel:
             length, l = parse_tl_num(buf, pos)
             pos += l
             if length == 1:
-                value = struct.unpack_from('!B', buf, pos)[0]
+                value = unpack_from('!B', buf, pos)[0]
             elif length == 2:
-                value = struct.unpack_from('!H', buf, pos)[0]
+                value = unpack_from('!H', buf, pos)[0]
             elif length == 4:
-                value = struct.unpack_from('!I', buf, pos)[0]
+                value = unpack_from('!I', buf, pos)[0]
             elif length == 8:
-                value = struct.unpack_from('!Q', buf, pos)[0]
+                value = unpack_from('!Q', buf, pos)[0]
             else:
                 return None
             pos += length
@@ -99,8 +99,7 @@ class StateVectorModel:
 #   to allow an easier time to interact with the StateVectorModel class.
 class StateVector:
     def __init__(self, component:Component=None) -> None:
-        self.vector = StateVectorModel()
-        self.vector.value = []
+        self.vector = StateVectorModel([])
         if component:
             temp_vector = StateVectorModel.parse(component)
             for i in temp_vector.value:
@@ -133,10 +132,7 @@ class StateVector:
                 return index
         return None
     def to_str(self) -> str:
-        stream = ""
-        for i in self.vector.value:
-            stream = stream + bytes(i.nid).decode() + ":" + str(i.seqno) + " "
-        return stream.rstrip()
+        return " ".join([( bytes(i.nid).decode() + ":" + str(i.seqno) ) for i in self.vector.value])
     def encode(self) -> bytes:
         return self.vector.encode()
     def keys(self) -> List[str]:
@@ -148,10 +144,7 @@ class StateVector:
     def length(self) -> int:
         return len(self.encode())
     def partition(self, start:int, end:int) -> Component:
-        part = self.vector.value[start:end]
-        if part == []:
-            return StateVectorModel().encode()
-        return StateVectorModel(part).encode()
+        return StateVectorModel(self.vector.value[start:end]).encode()
     def entry(self, index:int) -> Optional[StateVectorComponentModel]:
         try:
             return self.vector.value[index]
