@@ -7,13 +7,12 @@
 # Basic Libraries
 from typing import Optional, Callable
 # NDN Imports
-from ndn.app import NDNApp
 from ndn.transport.stream_socket import Face
 from ndn.encoding import Name
 from ndn.security import Keychain
 from ndn_python_repo import Storage
 # Custom Imports
-from .svs_thread_base import SVSyncBase_Thread
+from .svs_base_thread import SVSyncBase_Thread
 from .svs_shared import SVSyncShared
 from .security import SecurityOptions
 
